@@ -3,7 +3,7 @@ package ColorTheme::Harmony::Monochromatic;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-08'; # DATE
 our $DIST = 'ColorTheme-Harmony-Monochromatic'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -106,10 +106,17 @@ ColorTheme::Harmony::Monochromatic - Create a monochromatic color theme
 
 =head1 VERSION
 
-This document describes version 0.002 of ColorTheme::Harmony::Monochromatic (from Perl distribution ColorTheme-Harmony-Monochromatic), released on 2020-06-08.
+This document describes version 0.003 of ColorTheme::Harmony::Monochromatic (from Perl distribution ColorTheme-Harmony-Monochromatic), released on 2020-06-08.
 
 =head1 DESCRIPTION
 
+All the colors in the theme will have the same hue I<h>, but different saturation
+(between I<s1> and I<s2>) and brightness (between I<v1> and I<v2>).
+
+Example to see on the terminal:
+
+ % show-color-theme-swatch Harmony::Monochromatic -A h=86
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/ColorTheme-Harmony-Monochromatic>.
